<?xml version="1.0" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">	
   
   <!-- ==================================================================== -->
   <!-- cab_csyscfg.xsl                                                      -->
   <!-- (c) cab Produkttechnik GmbH & Co KG, Karlsruhe, DE, 2007             -->
   <!-- Author:  Bernd Kusterer                                              -->
   <!-- Version: 1.0                                                         -->
   <!-- ==================================================================== -->
   
   <xsl:template match="/">
      <html>
         <head>
            <title>Printer configuration</title>
            <meta http-equiv="Content-Type" content="text/html; charset=utf-8"/>
            <style type="text/css">
               h1 { font : 12px Arial, Helvetica, sans-serif; }
               h2 { font : 10px Arial, Helvetica, sans-serif; }
               th { font : 8px Arial, Helvetica, sans-serif; background-color : #b9c1d6; vertical-align: top; width: 25%; }
               td { font : 8px Arial, Helvetica, sans-serif; background-color : #f0f0f0; vertical-align: top; width: 75%; }
            </style>	
         </head>
         <body>
            <h1>Printer configuration</h1>
            <h2>Basic file information</h2>
            
            <!-- Table: Basic file information -->
            <table cellpadding="2" cellspacing="2" width="400">
               <xsl:for-each select="/CSYSCFG/Header">
                  <tr>	
                     <th>Type</th><td><xsl:value-of select="Type" /></td>	
                  </tr>
                  <tr>	
                     <th>User</th><td><xsl:value-of select="Username"/></td>
                  </tr>	
                  <tr>
                     <th>Date</th><td><xsl:value-of select="Date"/></td>
                  </tr>
                  <tr>
                     <th>Version-ID</th><td><xsl:value-of select="UserVersion"/></td>
                  </tr>
                  <tr>
                     <th>Description</th><td><xsl:value-of select="Description"/></td>
                  </tr>
                  <tr>
                     <th>Printer type</th><td><xsl:value-of select="PrinterType"/></td>
                  </tr>
                  <tr>
                     <th>Printer address</th><td><xsl:value-of select="PrinterAddress"/></td>
                  </tr>
                  <tr>
                     <th>Firmware</th><td><xsl:value-of select="Firmware"/></td>
                  </tr>
                  <tr>
                     <th>Information</th>
                     <td><xsl:value-of select="InfoText"/></td>
                  </tr>	
               </xsl:for-each>	
            </table>
            <!-- End of Table: Basic file information -->
            
            <h2>Detailed printer configuration</h2>
            
            <!-- Table: Detailed printer configuration -->
            <table cellpadding="2" cellspacing="2" align="left" width="400">
               
               <tr>
                  <td rowspan="2" colspan="1"></td>
                  <th rowspan="2" colspan="1" align="center" valign="middle">SNMP Trap 1</th>
                  <th rowspan="2" colspan="1" align="center" valign="middle">SNMP Trap 2</th>
                  <th rowspan="2" colspan="1" align="center" valign="middle">e-Mail</th>
                  <th rowspan="1" colspan="2" align="center">Sound</th>
               </tr>
               <tr>
                  <th>Name</th>
                  <th>Repeat</th>
               </tr>
               
               <xsl:for-each select="/CSYSCFG/Data/Element">
                  
                  <xsl:variable name="snmp1"       select="substring-before(Value, ';')"/>
                  <xsl:variable name="value2"      select="substring-after(Value, ';')"/>
                  
                  <xsl:variable name="snmp2"       select="substring-before($value2, ';')"/>
                  <xsl:variable name="value3"      select="substring-after($value2, ';')"/>
                  
                  <xsl:variable name="temail"      select="substring-before($value3, ';')"/> 
                  <xsl:variable name="value4"      select="substring-after($value3, ';')"/>
                  
                  <xsl:variable name="tsoundname"  select="substring-before($value4, ';')"/>
                  <xsl:variable name="value5"      select="substring-after($value4, ';')"/>
                  
                  <xsl:variable name="tsoundrepeat" select="substring-before($value5, ';')"/>
                  
                  <tr>
                     <th><xsl:value-of select="Description"/></th>
                     <xsl:choose>  
                        <xsl:when test="$snmp1='1'">  
                           <td align="center">X</td>			
                        </xsl:when>
                        
                        <xsl:otherwise>
                           <td align="center">-</td>			
                        </xsl:otherwise> 
                     </xsl:choose>	
                     
                     
                     <xsl:choose>  
                        <xsl:when test="$snmp2='1'">  
                           <td align="center">X</td>			
                        </xsl:when>
                        
                        <xsl:otherwise>
                           <td align="center">-</td>			
                        </xsl:otherwise> 
                     </xsl:choose>
                     
                     
                     <xsl:choose>  
                        <xsl:when test="$temail=''">
                           <xsl:variable name="email"       select="'-'"/>  
                           <td align="center"><xsl:value-of select="$email"/></td>			
                        </xsl:when>
                        
                        <xsl:otherwise>
                           <xsl:variable name="email" select="$temail"/> 
                           <td align="center"><xsl:value-of select="$email"/></td>			
                        </xsl:otherwise> 
                     </xsl:choose>	
                     
                     
                     <xsl:choose>  
                        <xsl:when test="$tsoundname=''">
                           <xsl:variable name="soundname" select="'-'"/>  
                           <td align="center"><xsl:value-of select="$soundname"/></td>		
                        </xsl:when>
                        
                        <xsl:otherwise>
                           <xsl:variable name="soundname"       select="$tsoundname"/> 
                           <td align="center"><xsl:value-of select="$soundname"/></td>	
                        </xsl:otherwise> 
                     </xsl:choose>	
                     
                     
                     <xsl:choose>  
                        <xsl:when test="$tsoundrepeat=''">
                           <xsl:variable name="soundrepeat" select="'-'"/>  
                           <td align="center"><xsl:value-of select="$soundrepeat"/></td>	
                        </xsl:when>
                        
                        <xsl:otherwise>
                           <xsl:variable name="soundrepeat" select="$tsoundrepeat"/> 
                           <td align="center"><xsl:value-of select="$soundrepeat"/></td>		
                        </xsl:otherwise> 
                     </xsl:choose>					
                  </tr>	
               </xsl:for-each>
               
            </table>
            <!-- End of Table: Detailed printer configuration -->
            
         </body>
      </html>
   </xsl:template>
</xsl:stylesheet>
<!-- End of cab_csyscfg.xsl -->
